@@ -71,9 +71,8 @@ outputMatchers = {
     'error': re.compile(r"^\S+:(?P<level>\w+):(?P<code>(?!57|64)\d+):\s+(?P<msg>.*)$"),
     # available with --terse has one module per line
     # matches modules such as "ictce/3.2.1.015.u4"
-    # line ending with : is ignored (the modulepath in --terse)
-    # FIXME: --terse ignores defaultness
-    'available': re.compile(r"^\s*(?P<mod_name>[^\(\s:]+)\s*[^:\S]*$")
+    # lines ending in ':' are ignored (the modulepath(s) in --terse)
+    'available': re.compile(r"^\s*(?P<mod_name>[^\(\s:]+)(?P<default>\(default\))?\s*[^:\S]*$"),
 }
 
 _log = fancylogger.getLogger('modules', fname=False)
