@@ -31,6 +31,7 @@ Interface module to TORQUE (PBS).
 """
 
 import os
+import time
 from vsc import fancylogger
 
 _log = fancylogger.getLogger('pbs_job', fname=False)
@@ -219,11 +220,12 @@ class PbsJob(object):
 
         # extend paramater should be 'NULL' because this is required by the python api
         extend = 'NULL'
+        # job submission sometimes fails without producing an error, e.g. when one of the dependency jobs has already finished
+        # when that occurs, None will be returned by pbs_submit as job id
         jobid = pbs.pbs_submit(self.pbsconn, pbs_attributes, scriptfn, self.queue, extend)
-
         is_error, errormsg = pbs.error()
-        if is_error:
-            self.log.error("Failed to submit job script %s: error %s" % (scriptfn, errormsg))
+        if is_error or jobid is None:
+            self.log.error("Failed to submit job script %s (job id: %s, error %s)" % (scriptfn, jobid, errormsg))
         else:
             self.log.debug("Succesful job submission returned jobid %s" % jobid)
             self.jobid = jobid
